@@ -6,7 +6,7 @@ from sqlglot import exp
 from sqlglot.errors import OptimizeError
 from sqlglot.helper import while_changing
 from sqlglot.optimizer.scope import find_all_in_scope
-from sqlglot.optimizer.simplify import flatten, rewrite_between, uniq_sort
+from sqlglot.optimizer.simplify import Simplifier, flatten
 
 logger = logging.getLogger("sqlglot")
 
@@ -28,15 +28,17 @@ def normalize(expression: exp.Expression, dnf: bool = False, max_distance: int =
     Returns:
         sqlglot.Expression: normalized expression
     """
-    for node, *_ in tuple(expression.walk(prune=lambda e, *_: isinstance(e, exp.Connector))):
+    simplifier = Simplifier(annotate_new_expressions=False)
+
+    for node in tuple(expression.walk(prune=lambda e: isinstance(e, exp.Connector))):
         if isinstance(node, exp.Connector):
             if normalized(node, dnf=dnf):
                 continue
             root = node is expression
             original = node.copy()
 
-            node.transform(rewrite_between, copy=False)
-            distance = normalization_distance(node, dnf=dnf)
+            node.transform(simplifier.rewrite_between, copy=False)
+            distance = normalization_distance(node, dnf=dnf, max_=max_distance)
 
             if distance > max_distance:
                 logger.info(
@@ -46,7 +48,10 @@ def normalize(expression: exp.Expression, dnf: bool = False, max_distance: int =
 
             try:
                 node = node.replace(
-                    while_changing(node, lambda e: distributive_law(e, dnf, max_distance))
+                    while_changing(
+                        node,
+                        lambda e: distributive_law(e, dnf, max_distance, simplifier=simplifier),
+                    )
                 )
             except OptimizeError as e:
                 logger.info(e)
@@ -85,7 +90,9 @@ def normalized(expression: exp.Expression, dnf: bool = False) -> bool:
     )
 
 
-def normalization_distance(expression: exp.Expression, dnf: bool = False) -> int:
+def normalization_distance(
+    expression: exp.Expression, dnf: bool = False, max_: float = float("inf")
+) -> int:
     """
     The difference in the number of predicates between a given expression and its normalized form.
 
@@ -101,36 +108,50 @@ def normalization_distance(expression: exp.Expression, dnf: bool = False) -> int
         expression: The expression to compute the normalization distance for.
         dnf: Whether to check if the expression is in Disjunctive Normal Form (DNF).
             Default: False, i.e. we check if it's in Conjunctive Normal Form (CNF).
+        max_: stop early if count exceeds this.
 
     Returns:
         The normalization distance.
     """
-    return sum(_predicate_lengths(expression, dnf)) - (
-        sum(1 for _ in expression.find_all(exp.Connector)) + 1
-    )
+    total = -(sum(1 for _ in expression.find_all(exp.Connector)) + 1)
+
+    for length in _predicate_lengths(expression, dnf, max_):
+        total += length
+        if total > max_:
+            return total
+
+    return total
 
 
-def _predicate_lengths(expression, dnf):
+def _predicate_lengths(expression, dnf, max_=float("inf"), depth=0):
     """
     Returns a list of predicate lengths when expanded to normalized form.
 
     (A AND B) OR C -> [2, 2] because len(A OR C), len(B OR C).
     """
+    if depth > max_:
+        yield depth
+        return
+
     expression = expression.unnest()
 
     if not isinstance(expression, exp.Connector):
-        return (1,)
+        yield 1
+        return
 
+    depth += 1
     left, right = expression.args.values()
 
     if isinstance(expression, exp.And if dnf else exp.Or):
-        return tuple(
-            a + b for a in _predicate_lengths(left, dnf) for b in _predicate_lengths(right, dnf)
-        )
-    return _predicate_lengths(left, dnf) + _predicate_lengths(right, dnf)
+        for a in _predicate_lengths(left, dnf, max_, depth):
+            for b in _predicate_lengths(right, dnf, max_, depth):
+                yield a + b
+    else:
+        yield from _predicate_lengths(left, dnf, max_, depth)
+        yield from _predicate_lengths(right, dnf, max_, depth)
 
 
-def distributive_law(expression, dnf, max_distance):
+def distributive_law(expression, dnf, max_distance, simplifier=None):
     """
     x OR (y AND z) -> (x OR y) AND (x OR z)
     (x AND y) OR (y AND z) -> (x OR y) AND (x OR z) AND (y OR y) AND (y OR z)
@@ -138,7 +159,7 @@ def distributive_law(expression, dnf, max_distance):
     if normalized(expression, dnf=dnf):
         return expression
 
-    distance = normalization_distance(expression, dnf=dnf)
+    distance = normalization_distance(expression, dnf=dnf, max_=max_distance)
 
     if distance > max_distance:
         raise OptimizeError(f"Normalization distance {distance} exceeds max {max_distance}")
@@ -152,32 +173,34 @@ def distributive_law(expression, dnf, max_distance):
         from_func = exp.and_ if from_exp == exp.And else exp.or_
         to_func = exp.and_ if to_exp == exp.And else exp.or_
 
+        simplifier = simplifier or Simplifier(annotate_new_expressions=False)
+
         if isinstance(a, to_exp) and isinstance(b, to_exp):
             if len(tuple(a.find_all(exp.Connector))) > len(tuple(b.find_all(exp.Connector))):
-                return _distribute(a, b, from_func, to_func)
-            return _distribute(b, a, from_func, to_func)
+                return _distribute(a, b, from_func, to_func, simplifier)
+            return _distribute(b, a, from_func, to_func, simplifier)
         if isinstance(a, to_exp):
-            return _distribute(b, a, from_func, to_func)
+            return _distribute(b, a, from_func, to_func, simplifier)
         if isinstance(b, to_exp):
-            return _distribute(a, b, from_func, to_func)
+            return _distribute(a, b, from_func, to_func, simplifier)
 
     return expression
 
 
-def _distribute(a, b, from_func, to_func):
+def _distribute(a, b, from_func, to_func, simplifier):
     if isinstance(a, exp.Connector):
         exp.replace_children(
             a,
             lambda c: to_func(
-                uniq_sort(flatten(from_func(c, b.left))),
-                uniq_sort(flatten(from_func(c, b.right))),
+                simplifier.uniq_sort(flatten(from_func(c, b.left))),
+                simplifier.uniq_sort(flatten(from_func(c, b.right))),
                 copy=False,
             ),
         )
     else:
         a = to_func(
-            uniq_sort(flatten(from_func(a, b.left))),
-            uniq_sort(flatten(from_func(a, b.right))),
+            simplifier.uniq_sort(flatten(from_func(a, b.left))),
+            simplifier.uniq_sort(flatten(from_func(a, b.right))),
             copy=False,
         )
 
