@@ -43,6 +43,12 @@ def unnest(select, parent_select, next_alias_name):
     predicate = select.find_ancestor(exp.Condition)
     if (
         not predicate
+        # Do not unnest subqueries inside table-valued functions such as
+        # FROM GENERATE_SERIES(...), FROM UNNEST(...) etc in order to preserve join order
+        or (
+            isinstance(predicate, exp.Func)
+            and isinstance(predicate.parent, (exp.Table, exp.From, exp.Join))
+        )
         or parent_select is not predicate.parent_select
         or not parent_select.args.get("from_")
     ):
@@ -83,6 +89,7 @@ def unnest(select, parent_select, next_alias_name):
 
         _replace(select.parent, column)
         parent_select.join(select, on=on_clause, join_type=join_type, join_alias=alias, copy=False)
+
         return
 
     if select.find(exp.Limit, exp.Offset):
